@@ -39,20 +39,11 @@ The code is extended with Clenshaw-Curtis and Fejer quadrature rules [1]
 
 @copyright: 2007 Florian Heiss, Viktor Winschel
 
-@copyright: 2012 Daniele Bigoni
+@copyright: 2012-2014 Daniele Bigoni
 
 .. [1]: Waldvogel, J. (2006). Fast Construction of the Fejér and Clenshaw–Curtis Quadrature Rules. Bit Numerical Mathematics, 46(1), 195–202. doi:10.1007/s10543-006-0045-4
 """
 
-__revision__ = filter(str.isdigit, "$Revision: 115 $")
-
-__author__ = "Florian Heiss, Viktor Winschel, and Daniele Bigoni"
-__copyright__ = """Copyright 2012, Florian Heiss, Viktor Winschel, Daniele Bigoni"""
-__credits__ = ["Florian Heiss", "Viktor Winschel", "Daniele Bigoni"]
-__maintainer__ = "Daniele Bigoni"
-__email__ = "dabi@imm.dtu.dk"
-__status__ = "Production"
-
 import numpy as np
 from numpy.fft import ifft
 
